@@ -9,18 +9,25 @@ except ImportError as import_error:
                              "package with [click] option")
     sys.exit(1)
 
-import logging
 import os
 from devo.common import Configuration
 from ..lookup import Lookup
-from ..data import Sender
+from ..data import Sender, DevoSenderException
+from devo.__version__ import __version__
 # Groups
 # ------------------------------------------------------------------------------
 
 
-@click.group()
-def cli():
+@click.group(invoke_without_command=True)
+@click.option('--version', "-v", is_flag=True, default=False)
+def cli(version):
     """ Initialize click """
+    pkg_dir =  os.path.abspath(os.path.join(
+        os.path.dirname(__file__), "..", "..",
+    ))
+    click.echo("devo-sdk {!s} from {!s} (python {!s})".format(__version__,
+                                                              pkg_dir,
+                                                              sys.version[:3]))
 
 
 # Commands
@@ -33,11 +40,6 @@ def cli():
 @click.option('--key', help='Devo user key cert file.')
 @click.option('--cert', help='Devo user cert file.')
 @click.option('--chain', help='Devo chain.crt file.')
-@click.option('--cert_reqs/--no-cert_reqs', help='Boolean to indicate if the '
-                                                 'shipment is done using '
-                                                 'security certificates or not.'
-                                                 ' Default True'
-              , default=True)
 @click.option('--multiline/--no-multiline', help='Flag for multiline (With '
                                                  'break-line in msg). '
                                                  'Default False', default=False)
@@ -55,11 +57,13 @@ def cli():
                                      'them.', default=False)
 @click.option('--raw', is_flag=True, help='Send raw events from a '
                                           'file when using --file')
+@click.option('--debug/--no-debug', help='For testing purposes', default=False)
 def data(**kwargs):
     """Send data to devo"""
     config = configure(kwargs)
+    sended = 0
     try:
-        con = Sender.from_config(config)
+        con = Sender(config=config)
         if config['file']:
             if not os.path.isfile(config['file']):
                 print_error(str("File not exist"))
@@ -68,22 +72,31 @@ def data(**kwargs):
                 with open(config['file'], 'r') as file:
                     content = file.read()
                     if not config['raw']:
-                        con.send(tag=config['tag'], msg=content,
-                                 multiline=config['multiline'])
+                        sended += con.send(tag=config['tag'], msg=content,
+                                           multiline=config['multiline'])
                     else:
-                        con.send_raw(content, multiline=config['multiline'])
+                        sended += con.send_raw(content,
+                                               multiline=config['multiline'])
             else:
                 with open(config['file']) as file:
                     if config['header']:
                         next(file)
                     for line in file:
                         if config['raw']:
-                            con.send_raw(line)
+                            sended += con.send_raw(line)
                         else:
-                            con.send(tag=config['tag'], msg=line)
+                            sended += con.send(tag=config['tag'], msg=line)
         else:
-            con.send(tag=config['tag'], msg=config['line'])
+            sended += con.send(tag=config['tag'], msg=config['line'])
 
+        con.close()
+        if config.get("debug", False):
+            click.echo("Sended: %s" % str(sended))
+    except DevoSenderException as error:
+        print_error(str(error))
+        if config.get('debug', False):
+            raise DevoSenderException(str(error))
+        exit()
     except Exception as error:
         print_error(str(error))
 
@@ -96,15 +109,10 @@ def data(**kwargs):
 @click.option('--default', '-d', help='Use default file for configuration',
               default=False)
 @click.option('--url', '--address', '-a', help='Devo relay address')
-@click.option('--port', '-p', help='Devo relay address port')
+@click.option('--port', '-p', default=443, help='Devo relay address port')
 @click.option('--key', help='Devo user key cert file.')
 @click.option('--cert', help='Devo user cert file.')
 @click.option('--chain', help='Devo chain.crt file.')
-@click.option('--cert_reqs/--no-cert_reqs', help='Boolean to indicate if the '
-                                                 'shipment is done using '
-                                                 'security certificates or not.'
-                                                 ' Default True'
-              , default=True)
 @click.option('--type', help='Connection type: SSL or TCP', default="SSL")
 @click.option('--name', '-n', help='Name for Lookup.')
 @click.option('--file', '-f', help='The file that you want to send to Devo,'
@@ -114,19 +122,17 @@ def data(**kwargs):
                                     'that appears in the header.')
 @click.option('--delimiter', '-d', help='CSV Delimiter char.', default=",")
 @click.option('--quotechar', '-qc', help='CSV Quote char.', default='"')
+@click.option('--debug/--no-debug', help='For testing purposes', default=False)
 def lookup(**kwargs):
     """Send csv lookups to devo"""
     config = configure_lookup(kwargs)
-    con = Sender.from_config(config)
-    logger = logging.getLogger("lt")
-    logger.setLevel(logging.DEBUG)
-    logger.addHandler(con)
-    look_up = Lookup(name=config['name'], historic_tag=None, con=con)
+    con = Sender(config=config)
+    lookup = Lookup(name=config['name'], historic_tag=None, con=con)
 
     with open(config['file']) as file:
         line = file.readline()
 
-        look_up.send_csv(config['file'], delimiter=config['delimiter'],
+        lookup.send_csv(config['file'], delimiter=config['delimiter'],
                          quotechar=config['quotechar'],
                          headers=line.rstrip().split(config['delimiter']),
                          key=config['lkey'])
@@ -134,7 +140,7 @@ def lookup(**kwargs):
 
 def configure(args):
     """ Configuration of Sender CLI """
-    return init_conf(args).get()
+    return init_conf(args)
 
 
 def init_conf(args):
@@ -157,23 +163,23 @@ def init_conf(args):
             config.load_default_config(section="sender")
     finally:
         config.mix(dict(args))
-        return config.get()
+        return config
 
 
 def configure_lookup(args):
     """ Configuration of Lookup for CLI """
     config = init_conf(args)
-    config.load_config(args.get('config'), 'lookup')
-    config.mix(dict(args))
+    if args.get('config'):
+        config.load_config(args.get('config'), 'lookup')
+    if "url" in config.keys():
+        config.set("address", config.get("url"))
 
-    return config.get()
+    return config
 
 
-def print_error(error, show_help=False, stop=True):
-    """ Generic class for show errors with help """
-    click.echo(click.style(error, fg='red'), err=True)
+def print_error(error, show_help=False):
+    """Class for print error in shell when exception"""
     if show_help:
         click.echo("")
         click.echo(click.get_current_context().get_help())
-    if stop:
-        sys.exit(1)
+    click.echo(click.style(error, fg='red'), err=True)
\ No newline at end of file
